@@ -20,8 +20,6 @@ from botocore.client import ClientMeta
 
 from .literals import SourceTypeType
 from .paginator import (
-    DBInstanceAvailableWaiter,
-    DBInstanceDeletedWaiter,
     DescribeCertificatesPaginator,
     DescribeDBClusterParameterGroupsPaginator,
     DescribeDBClusterParametersPaginator,
@@ -84,6 +82,7 @@ from .type_defs import (
     TagListMessageTypeDef,
     TagTypeDef,
 )
+from .waiter import DBInstanceAvailableWaiter, DBInstanceDeletedWaiter
 
 if sys.version_info >= (3, 8):
     from typing import Literal
@@ -161,7 +160,7 @@ class Exceptions:
 
 class DocDBClient:
     """
-    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.72/reference/services/docdb.html#DocDB.Client)
+    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.73/reference/services/docdb.html#DocDB.Client)
     [Show boto3-stubs documentation](./client.md)
     """
 
@@ -172,13 +171,13 @@ class DocDBClient:
         self, SubscriptionName: str, SourceIdentifier: str
     ) -> AddSourceIdentifierToSubscriptionResultTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.72/reference/services/docdb.html#DocDB.Client.add_source_identifier_to_subscription)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.73/reference/services/docdb.html#DocDB.Client.add_source_identifier_to_subscription)
         [Show boto3-stubs documentation](./client.md#add_source_identifier_to_subscription)
         """
 
     def add_tags_to_resource(self, ResourceName: str, Tags: List["TagTypeDef"]) -> None:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.72/reference/services/docdb.html#DocDB.Client.add_tags_to_resource)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.73/reference/services/docdb.html#DocDB.Client.add_tags_to_resource)
         [Show boto3-stubs documentation](./client.md#add_tags_to_resource)
         """
 
@@ -186,13 +185,13 @@ class DocDBClient:
         self, ResourceIdentifier: str, ApplyAction: str, OptInType: str
     ) -> ApplyPendingMaintenanceActionResultTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.72/reference/services/docdb.html#DocDB.Client.apply_pending_maintenance_action)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.73/reference/services/docdb.html#DocDB.Client.apply_pending_maintenance_action)
         [Show boto3-stubs documentation](./client.md#apply_pending_maintenance_action)
         """
 
     def can_paginate(self, operation_name: str) -> bool:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.72/reference/services/docdb.html#DocDB.Client.can_paginate)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.73/reference/services/docdb.html#DocDB.Client.can_paginate)
         [Show boto3-stubs documentation](./client.md#can_paginate)
         """
 
@@ -204,7 +203,7 @@ class DocDBClient:
         Tags: List["TagTypeDef"] = None,
     ) -> CopyDBClusterParameterGroupResultTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.72/reference/services/docdb.html#DocDB.Client.copy_db_cluster_parameter_group)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.73/reference/services/docdb.html#DocDB.Client.copy_db_cluster_parameter_group)
         [Show boto3-stubs documentation](./client.md#copy_db_cluster_parameter_group)
         """
 
@@ -219,7 +218,7 @@ class DocDBClient:
         SourceRegion: str = None,
     ) -> CopyDBClusterSnapshotResultTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.72/reference/services/docdb.html#DocDB.Client.copy_db_cluster_snapshot)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.73/reference/services/docdb.html#DocDB.Client.copy_db_cluster_snapshot)
         [Show boto3-stubs documentation](./client.md#copy_db_cluster_snapshot)
         """
 
@@ -247,7 +246,7 @@ class DocDBClient:
         SourceRegion: str = None,
     ) -> CreateDBClusterResultTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.72/reference/services/docdb.html#DocDB.Client.create_db_cluster)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.73/reference/services/docdb.html#DocDB.Client.create_db_cluster)
         [Show boto3-stubs documentation](./client.md#create_db_cluster)
         """
 
@@ -259,7 +258,7 @@ class DocDBClient:
         Tags: List["TagTypeDef"] = None,
     ) -> CreateDBClusterParameterGroupResultTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.72/reference/services/docdb.html#DocDB.Client.create_db_cluster_parameter_group)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.73/reference/services/docdb.html#DocDB.Client.create_db_cluster_parameter_group)
         [Show boto3-stubs documentation](./client.md#create_db_cluster_parameter_group)
         """
 
@@ -270,7 +269,7 @@ class DocDBClient:
         Tags: List["TagTypeDef"] = None,
     ) -> CreateDBClusterSnapshotResultTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.72/reference/services/docdb.html#DocDB.Client.create_db_cluster_snapshot)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.73/reference/services/docdb.html#DocDB.Client.create_db_cluster_snapshot)
         [Show boto3-stubs documentation](./client.md#create_db_cluster_snapshot)
         """
 
@@ -287,7 +286,7 @@ class DocDBClient:
         PromotionTier: int = None,
     ) -> CreateDBInstanceResultTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.72/reference/services/docdb.html#DocDB.Client.create_db_instance)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.73/reference/services/docdb.html#DocDB.Client.create_db_instance)
         [Show boto3-stubs documentation](./client.md#create_db_instance)
         """
 
@@ -299,7 +298,7 @@ class DocDBClient:
         Tags: List["TagTypeDef"] = None,
     ) -> CreateDBSubnetGroupResultTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.72/reference/services/docdb.html#DocDB.Client.create_db_subnet_group)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.73/reference/services/docdb.html#DocDB.Client.create_db_subnet_group)
         [Show boto3-stubs documentation](./client.md#create_db_subnet_group)
         """
 
@@ -314,7 +313,7 @@ class DocDBClient:
         Tags: List["TagTypeDef"] = None,
     ) -> CreateEventSubscriptionResultTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.72/reference/services/docdb.html#DocDB.Client.create_event_subscription)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.73/reference/services/docdb.html#DocDB.Client.create_event_subscription)
         [Show boto3-stubs documentation](./client.md#create_event_subscription)
         """
 
@@ -325,13 +324,13 @@ class DocDBClient:
         FinalDBSnapshotIdentifier: str = None,
     ) -> DeleteDBClusterResultTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.72/reference/services/docdb.html#DocDB.Client.delete_db_cluster)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.73/reference/services/docdb.html#DocDB.Client.delete_db_cluster)
         [Show boto3-stubs documentation](./client.md#delete_db_cluster)
         """
 
     def delete_db_cluster_parameter_group(self, DBClusterParameterGroupName: str) -> None:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.72/reference/services/docdb.html#DocDB.Client.delete_db_cluster_parameter_group)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.73/reference/services/docdb.html#DocDB.Client.delete_db_cluster_parameter_group)
         [Show boto3-stubs documentation](./client.md#delete_db_cluster_parameter_group)
         """
 
@@ -339,19 +338,19 @@ class DocDBClient:
         self, DBClusterSnapshotIdentifier: str
     ) -> DeleteDBClusterSnapshotResultTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.72/reference/services/docdb.html#DocDB.Client.delete_db_cluster_snapshot)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.73/reference/services/docdb.html#DocDB.Client.delete_db_cluster_snapshot)
         [Show boto3-stubs documentation](./client.md#delete_db_cluster_snapshot)
         """
 
     def delete_db_instance(self, DBInstanceIdentifier: str) -> DeleteDBInstanceResultTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.72/reference/services/docdb.html#DocDB.Client.delete_db_instance)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.73/reference/services/docdb.html#DocDB.Client.delete_db_instance)
         [Show boto3-stubs documentation](./client.md#delete_db_instance)
         """
 
     def delete_db_subnet_group(self, DBSubnetGroupName: str) -> None:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.72/reference/services/docdb.html#DocDB.Client.delete_db_subnet_group)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.73/reference/services/docdb.html#DocDB.Client.delete_db_subnet_group)
         [Show boto3-stubs documentation](./client.md#delete_db_subnet_group)
         """
 
@@ -359,7 +358,7 @@ class DocDBClient:
         self, SubscriptionName: str
     ) -> DeleteEventSubscriptionResultTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.72/reference/services/docdb.html#DocDB.Client.delete_event_subscription)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.73/reference/services/docdb.html#DocDB.Client.delete_event_subscription)
         [Show boto3-stubs documentation](./client.md#delete_event_subscription)
         """
 
@@ -371,7 +370,7 @@ class DocDBClient:
         Marker: str = None,
     ) -> CertificateMessageTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.72/reference/services/docdb.html#DocDB.Client.describe_certificates)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.73/reference/services/docdb.html#DocDB.Client.describe_certificates)
         [Show boto3-stubs documentation](./client.md#describe_certificates)
         """
 
@@ -383,7 +382,7 @@ class DocDBClient:
         Marker: str = None,
     ) -> DBClusterParameterGroupsMessageTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.72/reference/services/docdb.html#DocDB.Client.describe_db_cluster_parameter_groups)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.73/reference/services/docdb.html#DocDB.Client.describe_db_cluster_parameter_groups)
         [Show boto3-stubs documentation](./client.md#describe_db_cluster_parameter_groups)
         """
 
@@ -396,7 +395,7 @@ class DocDBClient:
         Marker: str = None,
     ) -> DBClusterParameterGroupDetailsTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.72/reference/services/docdb.html#DocDB.Client.describe_db_cluster_parameters)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.73/reference/services/docdb.html#DocDB.Client.describe_db_cluster_parameters)
         [Show boto3-stubs documentation](./client.md#describe_db_cluster_parameters)
         """
 
@@ -404,7 +403,7 @@ class DocDBClient:
         self, DBClusterSnapshotIdentifier: str
     ) -> DescribeDBClusterSnapshotAttributesResultTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.72/reference/services/docdb.html#DocDB.Client.describe_db_cluster_snapshot_attributes)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.73/reference/services/docdb.html#DocDB.Client.describe_db_cluster_snapshot_attributes)
         [Show boto3-stubs documentation](./client.md#describe_db_cluster_snapshot_attributes)
         """
 
@@ -420,7 +419,7 @@ class DocDBClient:
         IncludePublic: bool = None,
     ) -> DBClusterSnapshotMessageTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.72/reference/services/docdb.html#DocDB.Client.describe_db_cluster_snapshots)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.73/reference/services/docdb.html#DocDB.Client.describe_db_cluster_snapshots)
         [Show boto3-stubs documentation](./client.md#describe_db_cluster_snapshots)
         """
 
@@ -432,7 +431,7 @@ class DocDBClient:
         Marker: str = None,
     ) -> DBClusterMessageTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.72/reference/services/docdb.html#DocDB.Client.describe_db_clusters)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.73/reference/services/docdb.html#DocDB.Client.describe_db_clusters)
         [Show boto3-stubs documentation](./client.md#describe_db_clusters)
         """
 
@@ -449,7 +448,7 @@ class DocDBClient:
         ListSupportedTimezones: bool = None,
     ) -> DBEngineVersionMessageTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.72/reference/services/docdb.html#DocDB.Client.describe_db_engine_versions)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.73/reference/services/docdb.html#DocDB.Client.describe_db_engine_versions)
         [Show boto3-stubs documentation](./client.md#describe_db_engine_versions)
         """
 
@@ -461,7 +460,7 @@ class DocDBClient:
         Marker: str = None,
     ) -> DBInstanceMessageTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.72/reference/services/docdb.html#DocDB.Client.describe_db_instances)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.73/reference/services/docdb.html#DocDB.Client.describe_db_instances)
         [Show boto3-stubs documentation](./client.md#describe_db_instances)
         """
 
@@ -473,7 +472,7 @@ class DocDBClient:
         Marker: str = None,
     ) -> DBSubnetGroupMessageTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.72/reference/services/docdb.html#DocDB.Client.describe_db_subnet_groups)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.73/reference/services/docdb.html#DocDB.Client.describe_db_subnet_groups)
         [Show boto3-stubs documentation](./client.md#describe_db_subnet_groups)
         """
 
@@ -485,7 +484,7 @@ class DocDBClient:
         Marker: str = None,
     ) -> DescribeEngineDefaultClusterParametersResultTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.72/reference/services/docdb.html#DocDB.Client.describe_engine_default_cluster_parameters)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.73/reference/services/docdb.html#DocDB.Client.describe_engine_default_cluster_parameters)
         [Show boto3-stubs documentation](./client.md#describe_engine_default_cluster_parameters)
         """
 
@@ -493,7 +492,7 @@ class DocDBClient:
         self, SourceType: str = None, Filters: List[FilterTypeDef] = None
     ) -> EventCategoriesMessageTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.72/reference/services/docdb.html#DocDB.Client.describe_event_categories)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.73/reference/services/docdb.html#DocDB.Client.describe_event_categories)
         [Show boto3-stubs documentation](./client.md#describe_event_categories)
         """
 
@@ -505,7 +504,7 @@ class DocDBClient:
         Marker: str = None,
     ) -> EventSubscriptionsMessageTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.72/reference/services/docdb.html#DocDB.Client.describe_event_subscriptions)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.73/reference/services/docdb.html#DocDB.Client.describe_event_subscriptions)
         [Show boto3-stubs documentation](./client.md#describe_event_subscriptions)
         """
 
@@ -522,7 +521,7 @@ class DocDBClient:
         Marker: str = None,
     ) -> EventsMessageTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.72/reference/services/docdb.html#DocDB.Client.describe_events)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.73/reference/services/docdb.html#DocDB.Client.describe_events)
         [Show boto3-stubs documentation](./client.md#describe_events)
         """
 
@@ -538,7 +537,7 @@ class DocDBClient:
         Marker: str = None,
     ) -> OrderableDBInstanceOptionsMessageTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.72/reference/services/docdb.html#DocDB.Client.describe_orderable_db_instance_options)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.73/reference/services/docdb.html#DocDB.Client.describe_orderable_db_instance_options)
         [Show boto3-stubs documentation](./client.md#describe_orderable_db_instance_options)
         """
 
@@ -550,7 +549,7 @@ class DocDBClient:
         MaxRecords: int = None,
     ) -> PendingMaintenanceActionsMessageTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.72/reference/services/docdb.html#DocDB.Client.describe_pending_maintenance_actions)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.73/reference/services/docdb.html#DocDB.Client.describe_pending_maintenance_actions)
         [Show boto3-stubs documentation](./client.md#describe_pending_maintenance_actions)
         """
 
@@ -558,7 +557,7 @@ class DocDBClient:
         self, DBClusterIdentifier: str = None, TargetDBInstanceIdentifier: str = None
     ) -> FailoverDBClusterResultTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.72/reference/services/docdb.html#DocDB.Client.failover_db_cluster)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.73/reference/services/docdb.html#DocDB.Client.failover_db_cluster)
         [Show boto3-stubs documentation](./client.md#failover_db_cluster)
         """
 
@@ -570,7 +569,7 @@ class DocDBClient:
         HttpMethod: str = None,
     ) -> str:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.72/reference/services/docdb.html#DocDB.Client.generate_presigned_url)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.73/reference/services/docdb.html#DocDB.Client.generate_presigned_url)
         [Show boto3-stubs documentation](./client.md#generate_presigned_url)
         """
 
@@ -578,7 +577,7 @@ class DocDBClient:
         self, ResourceName: str, Filters: List[FilterTypeDef] = None
     ) -> TagListMessageTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.72/reference/services/docdb.html#DocDB.Client.list_tags_for_resource)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.73/reference/services/docdb.html#DocDB.Client.list_tags_for_resource)
         [Show boto3-stubs documentation](./client.md#list_tags_for_resource)
         """
 
@@ -599,7 +598,7 @@ class DocDBClient:
         DeletionProtection: bool = None,
     ) -> ModifyDBClusterResultTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.72/reference/services/docdb.html#DocDB.Client.modify_db_cluster)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.73/reference/services/docdb.html#DocDB.Client.modify_db_cluster)
         [Show boto3-stubs documentation](./client.md#modify_db_cluster)
         """
 
@@ -607,7 +606,7 @@ class DocDBClient:
         self, DBClusterParameterGroupName: str, Parameters: List["ParameterTypeDef"]
     ) -> DBClusterParameterGroupNameMessageTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.72/reference/services/docdb.html#DocDB.Client.modify_db_cluster_parameter_group)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.73/reference/services/docdb.html#DocDB.Client.modify_db_cluster_parameter_group)
         [Show boto3-stubs documentation](./client.md#modify_db_cluster_parameter_group)
         """
 
@@ -619,7 +618,7 @@ class DocDBClient:
         ValuesToRemove: List[str] = None,
     ) -> ModifyDBClusterSnapshotAttributeResultTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.72/reference/services/docdb.html#DocDB.Client.modify_db_cluster_snapshot_attribute)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.73/reference/services/docdb.html#DocDB.Client.modify_db_cluster_snapshot_attribute)
         [Show boto3-stubs documentation](./client.md#modify_db_cluster_snapshot_attribute)
         """
 
@@ -635,7 +634,7 @@ class DocDBClient:
         PromotionTier: int = None,
     ) -> ModifyDBInstanceResultTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.72/reference/services/docdb.html#DocDB.Client.modify_db_instance)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.73/reference/services/docdb.html#DocDB.Client.modify_db_instance)
         [Show boto3-stubs documentation](./client.md#modify_db_instance)
         """
 
@@ -643,7 +642,7 @@ class DocDBClient:
         self, DBSubnetGroupName: str, SubnetIds: List[str], DBSubnetGroupDescription: str = None
     ) -> ModifyDBSubnetGroupResultTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.72/reference/services/docdb.html#DocDB.Client.modify_db_subnet_group)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.73/reference/services/docdb.html#DocDB.Client.modify_db_subnet_group)
         [Show boto3-stubs documentation](./client.md#modify_db_subnet_group)
         """
 
@@ -656,7 +655,7 @@ class DocDBClient:
         Enabled: bool = None,
     ) -> ModifyEventSubscriptionResultTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.72/reference/services/docdb.html#DocDB.Client.modify_event_subscription)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.73/reference/services/docdb.html#DocDB.Client.modify_event_subscription)
         [Show boto3-stubs documentation](./client.md#modify_event_subscription)
         """
 
@@ -664,7 +663,7 @@ class DocDBClient:
         self, DBInstanceIdentifier: str, ForceFailover: bool = None
     ) -> RebootDBInstanceResultTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.72/reference/services/docdb.html#DocDB.Client.reboot_db_instance)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.73/reference/services/docdb.html#DocDB.Client.reboot_db_instance)
         [Show boto3-stubs documentation](./client.md#reboot_db_instance)
         """
 
@@ -672,13 +671,13 @@ class DocDBClient:
         self, SubscriptionName: str, SourceIdentifier: str
     ) -> RemoveSourceIdentifierFromSubscriptionResultTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.72/reference/services/docdb.html#DocDB.Client.remove_source_identifier_from_subscription)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.73/reference/services/docdb.html#DocDB.Client.remove_source_identifier_from_subscription)
         [Show boto3-stubs documentation](./client.md#remove_source_identifier_from_subscription)
         """
 
     def remove_tags_from_resource(self, ResourceName: str, TagKeys: List[str]) -> None:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.72/reference/services/docdb.html#DocDB.Client.remove_tags_from_resource)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.73/reference/services/docdb.html#DocDB.Client.remove_tags_from_resource)
         [Show boto3-stubs documentation](./client.md#remove_tags_from_resource)
         """
 
@@ -689,7 +688,7 @@ class DocDBClient:
         Parameters: List["ParameterTypeDef"] = None,
     ) -> DBClusterParameterGroupNameMessageTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.72/reference/services/docdb.html#DocDB.Client.reset_db_cluster_parameter_group)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.73/reference/services/docdb.html#DocDB.Client.reset_db_cluster_parameter_group)
         [Show boto3-stubs documentation](./client.md#reset_db_cluster_parameter_group)
         """
 
@@ -709,7 +708,7 @@ class DocDBClient:
         DeletionProtection: bool = None,
     ) -> RestoreDBClusterFromSnapshotResultTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.72/reference/services/docdb.html#DocDB.Client.restore_db_cluster_from_snapshot)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.73/reference/services/docdb.html#DocDB.Client.restore_db_cluster_from_snapshot)
         [Show boto3-stubs documentation](./client.md#restore_db_cluster_from_snapshot)
         """
 
@@ -728,19 +727,19 @@ class DocDBClient:
         DeletionProtection: bool = None,
     ) -> RestoreDBClusterToPointInTimeResultTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.72/reference/services/docdb.html#DocDB.Client.restore_db_cluster_to_point_in_time)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.73/reference/services/docdb.html#DocDB.Client.restore_db_cluster_to_point_in_time)
         [Show boto3-stubs documentation](./client.md#restore_db_cluster_to_point_in_time)
         """
 
     def start_db_cluster(self, DBClusterIdentifier: str) -> StartDBClusterResultTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.72/reference/services/docdb.html#DocDB.Client.start_db_cluster)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.73/reference/services/docdb.html#DocDB.Client.start_db_cluster)
         [Show boto3-stubs documentation](./client.md#start_db_cluster)
         """
 
     def stop_db_cluster(self, DBClusterIdentifier: str) -> StopDBClusterResultTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.72/reference/services/docdb.html#DocDB.Client.stop_db_cluster)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.73/reference/services/docdb.html#DocDB.Client.stop_db_cluster)
         [Show boto3-stubs documentation](./client.md#stop_db_cluster)
         """
 
@@ -749,7 +748,7 @@ class DocDBClient:
         self, operation_name: Literal["describe_certificates"]
     ) -> DescribeCertificatesPaginator:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.72/reference/services/docdb.html#DocDB.Paginator.DescribeCertificates)[Show boto3-stubs documentation](./paginators.md#describecertificatespaginator)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.73/reference/services/docdb.html#DocDB.Paginator.DescribeCertificates)[Show boto3-stubs documentation](./paginators.md#describecertificatespaginator)
         """
 
     @overload
@@ -757,7 +756,7 @@ class DocDBClient:
         self, operation_name: Literal["describe_db_cluster_parameter_groups"]
     ) -> DescribeDBClusterParameterGroupsPaginator:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.72/reference/services/docdb.html#DocDB.Paginator.DescribeDBClusterParameterGroups)[Show boto3-stubs documentation](./paginators.md#describedbclusterparametergroupspaginator)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.73/reference/services/docdb.html#DocDB.Paginator.DescribeDBClusterParameterGroups)[Show boto3-stubs documentation](./paginators.md#describedbclusterparametergroupspaginator)
         """
 
     @overload
@@ -765,7 +764,7 @@ class DocDBClient:
         self, operation_name: Literal["describe_db_cluster_parameters"]
     ) -> DescribeDBClusterParametersPaginator:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.72/reference/services/docdb.html#DocDB.Paginator.DescribeDBClusterParameters)[Show boto3-stubs documentation](./paginators.md#describedbclusterparameterspaginator)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.73/reference/services/docdb.html#DocDB.Paginator.DescribeDBClusterParameters)[Show boto3-stubs documentation](./paginators.md#describedbclusterparameterspaginator)
         """
 
     @overload
@@ -773,7 +772,7 @@ class DocDBClient:
         self, operation_name: Literal["describe_db_cluster_snapshots"]
     ) -> DescribeDBClusterSnapshotsPaginator:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.72/reference/services/docdb.html#DocDB.Paginator.DescribeDBClusterSnapshots)[Show boto3-stubs documentation](./paginators.md#describedbclustersnapshotspaginator)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.73/reference/services/docdb.html#DocDB.Paginator.DescribeDBClusterSnapshots)[Show boto3-stubs documentation](./paginators.md#describedbclustersnapshotspaginator)
         """
 
     @overload
@@ -781,7 +780,7 @@ class DocDBClient:
         self, operation_name: Literal["describe_db_clusters"]
     ) -> DescribeDBClustersPaginator:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.72/reference/services/docdb.html#DocDB.Paginator.DescribeDBClusters)[Show boto3-stubs documentation](./paginators.md#describedbclusterspaginator)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.73/reference/services/docdb.html#DocDB.Paginator.DescribeDBClusters)[Show boto3-stubs documentation](./paginators.md#describedbclusterspaginator)
         """
 
     @overload
@@ -789,7 +788,7 @@ class DocDBClient:
         self, operation_name: Literal["describe_db_engine_versions"]
     ) -> DescribeDBEngineVersionsPaginator:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.72/reference/services/docdb.html#DocDB.Paginator.DescribeDBEngineVersions)[Show boto3-stubs documentation](./paginators.md#describedbengineversionspaginator)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.73/reference/services/docdb.html#DocDB.Paginator.DescribeDBEngineVersions)[Show boto3-stubs documentation](./paginators.md#describedbengineversionspaginator)
         """
 
     @overload
@@ -797,7 +796,7 @@ class DocDBClient:
         self, operation_name: Literal["describe_db_instances"]
     ) -> DescribeDBInstancesPaginator:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.72/reference/services/docdb.html#DocDB.Paginator.DescribeDBInstances)[Show boto3-stubs documentation](./paginators.md#describedbinstancespaginator)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.73/reference/services/docdb.html#DocDB.Paginator.DescribeDBInstances)[Show boto3-stubs documentation](./paginators.md#describedbinstancespaginator)
         """
 
     @overload
@@ -805,7 +804,7 @@ class DocDBClient:
         self, operation_name: Literal["describe_db_subnet_groups"]
     ) -> DescribeDBSubnetGroupsPaginator:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.72/reference/services/docdb.html#DocDB.Paginator.DescribeDBSubnetGroups)[Show boto3-stubs documentation](./paginators.md#describedbsubnetgroupspaginator)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.73/reference/services/docdb.html#DocDB.Paginator.DescribeDBSubnetGroups)[Show boto3-stubs documentation](./paginators.md#describedbsubnetgroupspaginator)
         """
 
     @overload
@@ -813,13 +812,13 @@ class DocDBClient:
         self, operation_name: Literal["describe_event_subscriptions"]
     ) -> DescribeEventSubscriptionsPaginator:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.72/reference/services/docdb.html#DocDB.Paginator.DescribeEventSubscriptions)[Show boto3-stubs documentation](./paginators.md#describeeventsubscriptionspaginator)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.73/reference/services/docdb.html#DocDB.Paginator.DescribeEventSubscriptions)[Show boto3-stubs documentation](./paginators.md#describeeventsubscriptionspaginator)
         """
 
     @overload
     def get_paginator(self, operation_name: Literal["describe_events"]) -> DescribeEventsPaginator:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.72/reference/services/docdb.html#DocDB.Paginator.DescribeEvents)[Show boto3-stubs documentation](./paginators.md#describeeventspaginator)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.73/reference/services/docdb.html#DocDB.Paginator.DescribeEvents)[Show boto3-stubs documentation](./paginators.md#describeeventspaginator)
         """
 
     @overload
@@ -827,7 +826,7 @@ class DocDBClient:
         self, operation_name: Literal["describe_orderable_db_instance_options"]
     ) -> DescribeOrderableDBInstanceOptionsPaginator:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.72/reference/services/docdb.html#DocDB.Paginator.DescribeOrderableDBInstanceOptions)[Show boto3-stubs documentation](./paginators.md#describeorderabledbinstanceoptionspaginator)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.73/reference/services/docdb.html#DocDB.Paginator.DescribeOrderableDBInstanceOptions)[Show boto3-stubs documentation](./paginators.md#describeorderabledbinstanceoptionspaginator)
         """
 
     @overload
@@ -835,7 +834,7 @@ class DocDBClient:
         self, operation_name: Literal["describe_pending_maintenance_actions"]
     ) -> DescribePendingMaintenanceActionsPaginator:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.72/reference/services/docdb.html#DocDB.Paginator.DescribePendingMaintenanceActions)[Show boto3-stubs documentation](./paginators.md#describependingmaintenanceactionspaginator)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.73/reference/services/docdb.html#DocDB.Paginator.DescribePendingMaintenanceActions)[Show boto3-stubs documentation](./paginators.md#describependingmaintenanceactionspaginator)
         """
 
     @overload
@@ -843,11 +842,11 @@ class DocDBClient:
         self, waiter_name: Literal["db_instance_available"]
     ) -> DBInstanceAvailableWaiter:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.72/reference/services/docdb.html#DocDB.Waiter.db_instance_available)[Show boto3-stubs documentation](./waiters.md#dbinstanceavailablewaiter)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.73/reference/services/docdb.html#DocDB.Waiter.db_instance_available)[Show boto3-stubs documentation](./waiters.md#dbinstanceavailablewaiter)
         """
 
     @overload
     def get_waiter(self, waiter_name: Literal["db_instance_deleted"]) -> DBInstanceDeletedWaiter:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.72/reference/services/docdb.html#DocDB.Waiter.db_instance_deleted)[Show boto3-stubs documentation](./waiters.md#dbinstancedeletedwaiter)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.73/reference/services/docdb.html#DocDB.Waiter.db_instance_deleted)[Show boto3-stubs documentation](./waiters.md#dbinstancedeletedwaiter)
         """
